from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from ..dns_record_enviromental_variables import DnsRecord_EnviromentalVariables
    from ..dns_record_geolocation_info import DnsRecord_GeolocationInfo
    from ..dns_record_i_p_geo_location_info import DnsRecord_IPGeoLocationInfo

@dataclass
class DnsRecord(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The Accelerated property
    accelerated: Optional[bool] = None
    # The AcceleratedPullZoneId property
    accelerated_pull_zone_id: Optional[int] = None
    # The Comment property
    comment: Optional[str] = None
    # The Disabled property
    disabled: Optional[bool] = None
    # The EnviromentalVariables property
    enviromental_variables: Optional[List[DnsRecord_EnviromentalVariables]] = None
    # The Flags property
    flags: Optional[int] = None
    # The GeolocationInfo property
    geolocation_info: Optional[DnsRecord_GeolocationInfo] = None
    # The GeolocationLatitude property
    geolocation_latitude: Optional[float] = None
    # The GeolocationLongitude property
    geolocation_longitude: Optional[float] = None
    # The IPGeoLocationInfo property
    i_p_geo_location_info: Optional[DnsRecord_IPGeoLocationInfo] = None
    # The Id property
    id: Optional[int] = None
    # The LatencyZone property
    latency_zone: Optional[str] = None
    # The LinkName property
    link_name: Optional[str] = None
    # The MonitorStatus property
    monitor_status: Optional[float] = None
    # The MonitorType property
    monitor_type: Optional[float] = None
    # The Name property
    name: Optional[str] = None
    # The Port property
    port: Optional[int] = None
    # The Priority property
    priority: Optional[int] = None
    # The SmartRoutingType property
    smart_routing_type: Optional[float] = None
    # The Tag property
    tag: Optional[str] = None
    # The Ttl property
    ttl: Optional[float] = None
    # The Type property
    type: Optional[float] = None
    # The Value property
    value: Optional[str] = None
    # The Weight property
    weight: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DnsRecord:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DnsRecord
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DnsRecord()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from ..dns_record_enviromental_variables import DnsRecord_EnviromentalVariables
        from ..dns_record_geolocation_info import DnsRecord_GeolocationInfo
        from ..dns_record_i_p_geo_location_info import DnsRecord_IPGeoLocationInfo

        from ..dns_record_enviromental_variables import DnsRecord_EnviromentalVariables
        from ..dns_record_geolocation_info import DnsRecord_GeolocationInfo
        from ..dns_record_i_p_geo_location_info import DnsRecord_IPGeoLocationInfo

        fields: Dict[str, Callable[[Any], None]] = {
            "Accelerated": lambda n : setattr(self, 'accelerated', n.get_bool_value()),
            "AcceleratedPullZoneId": lambda n : setattr(self, 'accelerated_pull_zone_id', n.get_int_value()),
            "Comment": lambda n : setattr(self, 'comment', n.get_str_value()),
            "Disabled": lambda n : setattr(self, 'disabled', n.get_bool_value()),
            "EnviromentalVariables": lambda n : setattr(self, 'enviromental_variables', n.get_collection_of_object_values(DnsRecord_EnviromentalVariables)),
            "Flags": lambda n : setattr(self, 'flags', n.get_int_value()),
            "GeolocationInfo": lambda n : setattr(self, 'geolocation_info', n.get_object_value(DnsRecord_GeolocationInfo)),
            "GeolocationLatitude": lambda n : setattr(self, 'geolocation_latitude', n.get_float_value()),
            "GeolocationLongitude": lambda n : setattr(self, 'geolocation_longitude', n.get_float_value()),
            "IPGeoLocationInfo": lambda n : setattr(self, 'i_p_geo_location_info', n.get_object_value(DnsRecord_IPGeoLocationInfo)),
            "Id": lambda n : setattr(self, 'id', n.get_int_value()),
            "LatencyZone": lambda n : setattr(self, 'latency_zone', n.get_str_value()),
            "LinkName": lambda n : setattr(self, 'link_name', n.get_str_value()),
            "MonitorStatus": lambda n : setattr(self, 'monitor_status', n.get_float_value()),
            "MonitorType": lambda n : setattr(self, 'monitor_type', n.get_float_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "Port": lambda n : setattr(self, 'port', n.get_int_value()),
            "Priority": lambda n : setattr(self, 'priority', n.get_int_value()),
            "SmartRoutingType": lambda n : setattr(self, 'smart_routing_type', n.get_float_value()),
            "Tag": lambda n : setattr(self, 'tag', n.get_str_value()),
            "Ttl": lambda n : setattr(self, 'ttl', n.get_float_value()),
            "Type": lambda n : setattr(self, 'type', n.get_float_value()),
            "Value": lambda n : setattr(self, 'value', n.get_str_value()),
            "Weight": lambda n : setattr(self, 'weight', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("Accelerated", self.accelerated)
        writer.write_str_value("Comment", self.comment)
        writer.write_bool_value("Disabled", self.disabled)
        writer.write_collection_of_object_values("EnviromentalVariables", self.enviromental_variables)
        writer.write_int_value("Flags", self.flags)
        writer.write_float_value("GeolocationLatitude", self.geolocation_latitude)
        writer.write_float_value("GeolocationLongitude", self.geolocation_longitude)
        writer.write_str_value("LatencyZone", self.latency_zone)
        writer.write_float_value("MonitorType", self.monitor_type)
        writer.write_str_value("Name", self.name)
        writer.write_int_value("Port", self.port)
        writer.write_int_value("Priority", self.priority)
        writer.write_float_value("SmartRoutingType", self.smart_routing_type)
        writer.write_str_value("Tag", self.tag)
        writer.write_float_value("Ttl", self.ttl)
        writer.write_float_value("Type", self.type)
        writer.write_str_value("Value", self.value)
        writer.write_int_value("Weight", self.weight)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from ...models.stream_video_library.video_library import VideoLibrary
    from .add_allowed_referrer.add_allowed_referrer_request_builder import AddAllowedReferrerRequestBuilder
    from .add_blocked_referrer.add_blocked_referrer_request_builder import AddBlockedReferrerRequestBuilder
    from .remove_allowed_referrer.remove_allowed_referrer_request_builder import RemoveAllowedReferrerRequestBuilder
    from .remove_blocked_referrer.remove_blocked_referrer_request_builder import RemoveBlockedReferrerRequestBuilder
    from .reset_api_key.reset_api_key_request_builder import ResetApiKeyRequestBuilder
    from .videolibrary_post_request_body import VideolibraryPostRequestBody
    from .watermark.watermark_request_builder import WatermarkRequestBuilder

class VideolibraryItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /videolibrary/{id}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new VideolibraryItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/videolibrary/{id}?includeAccessKey={includeAccessKey}", path_parameters)
    
    async def delete(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> None:
        """
        [DeleteVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_delete)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: None
        """
        request_info = self.to_delete_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_no_response_content_async(request_info, None)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[VideolibraryItemRequestBuilderGetQueryParameters]] = None) -> Optional[VideoLibrary]:
        """
        [GetVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_index2)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[VideoLibrary]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ...models.stream_video_library.video_library import VideoLibrary

        return await self.request_adapter.send_async(request_info, VideoLibrary, None)
    
    async def post(self,body: VideolibraryPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[VideoLibrary]:
        """
        [UpdateVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_update)
        param body: The template for adding optional properties.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[VideoLibrary]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ...models.stream_video_library.video_library import VideoLibrary

        return await self.request_adapter.send_async(request_info, VideoLibrary, None)
    
    def to_delete_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        [DeleteVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_delete)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.DELETE, '{+baseurl}/videolibrary/{id}', self.path_parameters)
        request_info.configure(request_configuration)
        return request_info
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[VideolibraryItemRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [GetVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_index2)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: VideolibraryPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        [UpdateVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_update)
        param body: The template for adding optional properties.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, '{+baseurl}/videolibrary/{id}', self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> VideolibraryItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: VideolibraryItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return VideolibraryItemRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def add_allowed_referrer(self) -> AddAllowedReferrerRequestBuilder:
        """
        The addAllowedReferrer property
        """
        from .add_allowed_referrer.add_allowed_referrer_request_builder import AddAllowedReferrerRequestBuilder

        return AddAllowedReferrerRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def add_blocked_referrer(self) -> AddBlockedReferrerRequestBuilder:
        """
        The addBlockedReferrer property
        """
        from .add_blocked_referrer.add_blocked_referrer_request_builder import AddBlockedReferrerRequestBuilder

        return AddBlockedReferrerRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def remove_allowed_referrer(self) -> RemoveAllowedReferrerRequestBuilder:
        """
        The removeAllowedReferrer property
        """
        from .remove_allowed_referrer.remove_allowed_referrer_request_builder import RemoveAllowedReferrerRequestBuilder

        return RemoveAllowedReferrerRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def remove_blocked_referrer(self) -> RemoveBlockedReferrerRequestBuilder:
        """
        The removeBlockedReferrer property
        """
        from .remove_blocked_referrer.remove_blocked_referrer_request_builder import RemoveBlockedReferrerRequestBuilder

        return RemoveBlockedReferrerRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def reset_api_key(self) -> ResetApiKeyRequestBuilder:
        """
        The resetApiKey property
        """
        from .reset_api_key.reset_api_key_request_builder import ResetApiKeyRequestBuilder

        return ResetApiKeyRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def watermark(self) -> WatermarkRequestBuilder:
        """
        The watermark property
        """
        from .watermark.watermark_request_builder import WatermarkRequestBuilder

        return WatermarkRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class VideolibraryItemRequestBuilderDeleteRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class VideolibraryItemRequestBuilderGetQueryParameters():
        """
        [GetVideoLibrary API Docs](https://docs.bunny.net/reference/videolibrarypublic_index2)
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "include_access_key":
                return "includeAccessKey"
            return original_name
        
        include_access_key: Optional[bool] = None

    
    @dataclass
    class VideolibraryItemRequestBuilderGetRequestConfiguration(RequestConfiguration[VideolibraryItemRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class VideolibraryItemRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    




from __future__ import annotations
import datetime
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from ..pull_zone.pull_zone import PullZone
    from .edge_replication_regions import EdgeReplicationRegions
    from .standard_regions import StandardRegions

@dataclass
class StorageZone(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The Custom404FilePath property
    custom404_file_path: Optional[str] = None
    # The DateModified property
    date_modified: Optional[datetime.datetime] = None
    # The Deleted property
    deleted: Optional[bool] = None
    # The Discount property
    discount: Optional[int] = None
    # The FilesStored property
    files_stored: Optional[int] = None
    # The Id property
    id: Optional[int] = None
    # The Name property
    name: Optional[str] = None
    # The Password property
    password: Optional[str] = None
    # The PriceOverride property
    price_override: Optional[float] = None
    # The PullZones property
    pull_zones: Optional[List[PullZone]] = None
    # The ReadOnlyPassword property
    read_only_password: Optional[str] = None
    # The Region property
    region: Optional[StandardRegions] = None
    # The ReplicationChangeInProgress property
    replication_change_in_progress: Optional[bool] = None
    # The ReplicationRegions property
    replication_regions: Optional[List[EdgeReplicationRegions]] = None
    # The Rewrite404To200 property
    rewrite404_to200: Optional[bool] = None
    # The StorageHostname property
    storage_hostname: Optional[str] = None
    # The StorageUsed property
    storage_used: Optional[int] = None
    # The UserId property
    user_id: Optional[str] = None
    # The ZoneTier property
    zone_tier: Optional[float] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> StorageZone:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: StorageZone
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return StorageZone()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from ..pull_zone.pull_zone import PullZone
        from .edge_replication_regions import EdgeReplicationRegions
        from .standard_regions import StandardRegions

        from ..pull_zone.pull_zone import PullZone
        from .edge_replication_regions import EdgeReplicationRegions
        from .standard_regions import StandardRegions

        fields: Dict[str, Callable[[Any], None]] = {
            "Custom404FilePath": lambda n : setattr(self, 'custom404_file_path', n.get_str_value()),
            "DateModified": lambda n : setattr(self, 'date_modified', n.get_datetime_value()),
            "Deleted": lambda n : setattr(self, 'deleted', n.get_bool_value()),
            "Discount": lambda n : setattr(self, 'discount', n.get_int_value()),
            "FilesStored": lambda n : setattr(self, 'files_stored', n.get_int_value()),
            "Id": lambda n : setattr(self, 'id', n.get_int_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "Password": lambda n : setattr(self, 'password', n.get_str_value()),
            "PriceOverride": lambda n : setattr(self, 'price_override', n.get_float_value()),
            "PullZones": lambda n : setattr(self, 'pull_zones', n.get_collection_of_object_values(PullZone)),
            "ReadOnlyPassword": lambda n : setattr(self, 'read_only_password', n.get_str_value()),
            "Region": lambda n : setattr(self, 'region', n.get_enum_value(StandardRegions)),
            "ReplicationChangeInProgress": lambda n : setattr(self, 'replication_change_in_progress', n.get_bool_value()),
            "ReplicationRegions": lambda n : setattr(self, 'replication_regions', n.get_collection_of_enum_values(EdgeReplicationRegions)),
            "Rewrite404To200": lambda n : setattr(self, 'rewrite404_to200', n.get_bool_value()),
            "StorageHostname": lambda n : setattr(self, 'storage_hostname', n.get_str_value()),
            "StorageUsed": lambda n : setattr(self, 'storage_used', n.get_int_value()),
            "UserId": lambda n : setattr(self, 'user_id', n.get_str_value()),
            "ZoneTier": lambda n : setattr(self, 'zone_tier', n.get_float_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("Custom404FilePath", self.custom404_file_path)
        writer.write_str_value("Name", self.name)
        writer.write_enum_value("Region", self.region)
        writer.write_collection_of_enum_values("ReplicationRegions", self.replication_regions)
        writer.write_bool_value("Rewrite404To200", self.rewrite404_to200)
        writer.write_float_value("ZoneTier", self.zone_tier)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

@dataclass
class User(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The Id of the user
    account_id: Optional[str] = None
    # The remaining balance on the user's account
    balance: Optional[float] = None
    # The email where the invoices and billing messages will be sent
    billing_email: Optional[str] = None
    # The end date of the account's free trial. If this is in the past, the free trial has expired.
    billing_free_until_date: Optional[datetime.datetime] = None
    # The BillingType property
    billing_type: Optional[float] = None
    # The city of the user
    city: Optional[str] = None
    # The country name that the user is from
    company_name: Optional[str] = None
    # The Alpha2 country code that the user is from
    country: Optional[str] = None
    # The date when the user joined bunny.net
    date_joined: Optional[datetime.datetime] = None
    # Determines if the DPA was accepted by the user or not
    dpa_accepted: Optional[bool] = None
    # Determines the date on which the DPA was accepted
    dpa_date_accepted: Optional[datetime.datetime] = None
    # Determines which version of the DPA was accepted
    dpa_version_accepted: Optional[int] = None
    # The email of the user
    email: Optional[str] = None
    # Determines if the account's email has been successfully verified
    email_verified: Optional[bool] = None
    # Contains the list of available payment types for this account
    enabled_payment_types: Optional[List[str]] = None
    # The list of features that the user has enabled
    feature_flags: Optional[List[str]] = None
    # The first name of the user
    first_name: Optional[str] = None
    # The FreeTrialExtendedDate property
    free_trial_extended_date: Optional[datetime.datetime] = None
    # The HasCompleteBillingProfile property
    has_complete_billing_profile: Optional[bool] = None
    # The Id of the user
    id: Optional[str] = None
    # Determines whether the user used a Single Sign On account
    is_sso_account: Optional[bool] = None
    # The last name of the user
    last_name: Optional[str] = None
    # Determines if the payments are disabled on this account
    payments_disabled: Optional[bool] = None
    # Determines if the account should receive notification emails from bunny.net
    receive_notification_emails: Optional[bool] = None
    # Determines if the account should receive promotional emails from bunny.net
    receive_promotional_emails: Optional[bool] = None
    # Determines the roles that the user belongs to
    roles: Optional[List[str]] = None
    # The street address of the user
    street_address: Optional[str] = None
    # Determines if the user's account is suspended
    suspended: Optional[bool] = None
    # The total bandwidth used by the account.
    total_bandwidth_used: Optional[int] = None
    # The total free trial bandwidth limit for this account
    trial_bandwidth_limit: Optional[int] = None
    # Determines if the account has 2FA enabled
    two_factor_authentication_enabled: Optional[bool] = None
    # Returns the number of unread tickets on the user's account
    unread_support_ticket_count: Optional[int] = None
    # The billing VAT number of the account
    v_a_t_number: Optional[str] = None
    # The address zip code of the user
    zip_code: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> User:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: User
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return User()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        fields: Dict[str, Callable[[Any], None]] = {
            "AccountId": lambda n : setattr(self, 'account_id', n.get_str_value()),
            "Balance": lambda n : setattr(self, 'balance', n.get_float_value()),
            "BillingEmail": lambda n : setattr(self, 'billing_email', n.get_str_value()),
            "BillingFreeUntilDate": lambda n : setattr(self, 'billing_free_until_date', n.get_datetime_value()),
            "BillingType": lambda n : setattr(self, 'billing_type', n.get_float_value()),
            "City": lambda n : setattr(self, 'city', n.get_str_value()),
            "CompanyName": lambda n : setattr(self, 'company_name', n.get_str_value()),
            "Country": lambda n : setattr(self, 'country', n.get_str_value()),
            "DateJoined": lambda n : setattr(self, 'date_joined', n.get_datetime_value()),
            "DpaAccepted": lambda n : setattr(self, 'dpa_accepted', n.get_bool_value()),
            "DpaDateAccepted": lambda n : setattr(self, 'dpa_date_accepted', n.get_datetime_value()),
            "DpaVersionAccepted": lambda n : setattr(self, 'dpa_version_accepted', n.get_int_value()),
            "Email": lambda n : setattr(self, 'email', n.get_str_value()),
            "EmailVerified": lambda n : setattr(self, 'email_verified', n.get_bool_value()),
            "EnabledPaymentTypes": lambda n : setattr(self, 'enabled_payment_types', n.get_collection_of_primitive_values(str)),
            "FeatureFlags": lambda n : setattr(self, 'feature_flags', n.get_collection_of_primitive_values(str)),
            "FirstName": lambda n : setattr(self, 'first_name', n.get_str_value()),
            "FreeTrialExtendedDate": lambda n : setattr(self, 'free_trial_extended_date', n.get_datetime_value()),
            "HasCompleteBillingProfile": lambda n : setattr(self, 'has_complete_billing_profile', n.get_bool_value()),
            "Id": lambda n : setattr(self, 'id', n.get_str_value()),
            "IsSsoAccount": lambda n : setattr(self, 'is_sso_account', n.get_bool_value()),
            "LastName": lambda n : setattr(self, 'last_name', n.get_str_value()),
            "PaymentsDisabled": lambda n : setattr(self, 'payments_disabled', n.get_bool_value()),
            "ReceiveNotificationEmails": lambda n : setattr(self, 'receive_notification_emails', n.get_bool_value()),
            "ReceivePromotionalEmails": lambda n : setattr(self, 'receive_promotional_emails', n.get_bool_value()),
            "Roles": lambda n : setattr(self, 'roles', n.get_collection_of_primitive_values(str)),
            "StreetAddress": lambda n : setattr(self, 'street_address', n.get_str_value()),
            "Suspended": lambda n : setattr(self, 'suspended', n.get_bool_value()),
            "TotalBandwidthUsed": lambda n : setattr(self, 'total_bandwidth_used', n.get_int_value()),
            "TrialBandwidthLimit": lambda n : setattr(self, 'trial_bandwidth_limit', n.get_int_value()),
            "TwoFactorAuthenticationEnabled": lambda n : setattr(self, 'two_factor_authentication_enabled', n.get_bool_value()),
            "UnreadSupportTicketCount": lambda n : setattr(self, 'unread_support_ticket_count', n.get_int_value()),
            "VATNumber": lambda n : setattr(self, 'v_a_t_number', n.get_str_value()),
            "ZipCode": lambda n : setattr(self, 'zip_code', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("AccountId", self.account_id)
        writer.write_float_value("Balance", self.balance)
        writer.write_str_value("BillingEmail", self.billing_email)
        writer.write_datetime_value("BillingFreeUntilDate", self.billing_free_until_date)
        writer.write_float_value("BillingType", self.billing_type)
        writer.write_str_value("City", self.city)
        writer.write_str_value("CompanyName", self.company_name)
        writer.write_str_value("Country", self.country)
        writer.write_datetime_value("DateJoined", self.date_joined)
        writer.write_bool_value("DpaAccepted", self.dpa_accepted)
        writer.write_datetime_value("DpaDateAccepted", self.dpa_date_accepted)
        writer.write_int_value("DpaVersionAccepted", self.dpa_version_accepted)
        writer.write_str_value("Email", self.email)
        writer.write_bool_value("EmailVerified", self.email_verified)
        writer.write_collection_of_primitive_values("EnabledPaymentTypes", self.enabled_payment_types)
        writer.write_collection_of_primitive_values("FeatureFlags", self.feature_flags)
        writer.write_str_value("FirstName", self.first_name)
        writer.write_datetime_value("FreeTrialExtendedDate", self.free_trial_extended_date)
        writer.write_bool_value("HasCompleteBillingProfile", self.has_complete_billing_profile)
        writer.write_str_value("Id", self.id)
        writer.write_bool_value("IsSsoAccount", self.is_sso_account)
        writer.write_str_value("LastName", self.last_name)
        writer.write_bool_value("PaymentsDisabled", self.payments_disabled)
        writer.write_bool_value("ReceiveNotificationEmails", self.receive_notification_emails)
        writer.write_bool_value("ReceivePromotionalEmails", self.receive_promotional_emails)
        writer.write_collection_of_primitive_values("Roles", self.roles)
        writer.write_str_value("StreetAddress", self.street_address)
        writer.write_bool_value("Suspended", self.suspended)
        writer.write_int_value("TotalBandwidthUsed", self.total_bandwidth_used)
        writer.write_int_value("TrialBandwidthLimit", self.trial_bandwidth_limit)
        writer.write_bool_value("TwoFactorAuthenticationEnabled", self.two_factor_authentication_enabled)
        writer.write_int_value("UnreadSupportTicketCount", self.unread_support_ticket_count)
        writer.write_str_value("VATNumber", self.v_a_t_number)
        writer.write_str_value("ZipCode", self.zip_code)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .with_pull_zone_id_log.with_pull_zone_id_log_request_builder import WithPullZoneIdLogRequestBuilder

class WithMmWithDdWithYyRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /{mm}-{dd}-{yy}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]], dd: Optional[int] = None, mm: Optional[int] = None, yy: Optional[int] = None) -> None:
        """
        Instantiates a new WithMmWithDdWithYyRequestBuilder and sets the default values.
        param dd: The path parameter: dd
        param mm: The path parameter: mm
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        param yy: The path parameter: yy
        Returns: None
        """
        if isinstance(path_parameters, dict):
            path_parameters['dd'] = str(dd)
            path_parameters['mm'] = str(mm)
            path_parameters['yy'] = str(yy)
        super().__init__(request_adapter, "{+baseurl}/{mm}-{dd}-{yy}", path_parameters)
    
    def with_pull_zone_id_log(self,pull_zone_id: int) -> WithPullZoneIdLogRequestBuilder:
        """
        Builds and executes requests for operations under /{mm}-{dd}-{yy}/{pullZoneId}.log
        param pull_zone_id: The path parameter: pullZoneId
        Returns: WithPullZoneIdLogRequestBuilder
        """
        if pull_zone_id is None:
            raise TypeError("pull_zone_id cannot be null.")
        from .with_pull_zone_id_log.with_pull_zone_id_log_request_builder import WithPullZoneIdLogRequestBuilder

        return WithPullZoneIdLogRequestBuilder(self.request_adapter, self.path_parameters, pull_zone_id)
    




from __future__ import annotations
import datetime
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .replication_regions import ReplicationRegions
    from .video_library_apple_fair_play_drm import VideoLibrary_AppleFairPlayDrm
    from .video_library_google_widevine_drm import VideoLibrary_GoogleWidevineDrm

@dataclass
class VideoLibrary(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # Determines direct play URLs are enabled for the library
    allow_direct_play: Optional[bool] = None
    # Determines if the Early-Play feature is enabled
    allow_early_play: Optional[bool] = None
    # The list of allowed referrer domains allowed to access the library
    allowed_referrers: Optional[List[str]] = None
    # The API access key for the library. Only added when the includeAccessKey parameter is set.
    api_access_key: Optional[str] = None
    # The API key used for authenticating with the video library
    api_key: Optional[str] = None
    # The AppleFairPlayDrm property
    apple_fair_play_drm: Optional[VideoLibrary_AppleFairPlayDrm] = None
    # The bitrate used for encoding 1080p videos
    bitrate1080p: Optional[int] = None
    # The bitrate used for encoding 1440p videos
    bitrate1440p: Optional[int] = None
    # The bitrate used for encoding 2160p videos
    bitrate2160p: Optional[int] = None
    # The bitrate used for encoding 240p videos
    bitrate240p: Optional[int] = None
    # The bitrate used for encoding 360p videos
    bitrate360p: Optional[int] = None
    # The bitrate used for encoding 480p videos
    bitrate480p: Optional[int] = None
    # The bitrate used for encoding 720p videos
    bitrate720p: Optional[int] = None
    # Determines if the requests without a referrer are blocked
    block_none_referrer: Optional[bool] = None
    # The list of blocked referrer domains blocked from accessing the library
    blocked_referrers: Optional[List[str]] = None
    # The captions display background color
    captions_background: Optional[str] = None
    # The captions display font color
    captions_font_color: Optional[str] = None
    # The captions display font size
    captions_font_size: Optional[int] = None
    # The list of controls on the video player.
    controls: Optional[str] = None
    # The custom HTMl that is added into the head of the HTML player.
    custom_h_t_m_l: Optional[str] = None
    # The date when the video library was created
    date_created: Optional[datetime.datetime] = None
    # The DrmVersion property
    drm_version: Optional[int] = None
    # Determines if content tagging should be enabled for this library.
    enable_content_tagging: Optional[bool] = None
    # Determines if the MediaCage basic DRM is enabled
    enable_d_r_m: Optional[bool] = None
    # Determines if the MP4 fallback feature is enabled
    enable_m_p4_fallback: Optional[bool] = None
    # Determines if the automatic audio transcribing is currently enabled for this zone.
    enable_transcribing: Optional[bool] = None
    # Determines if automatic transcribing description generation is currently enabled.
    enable_transcribing_description_generation: Optional[bool] = None
    # Determines if automatic transcribing title generation is currently enabled.
    enable_transcribing_title_generation: Optional[bool] = None
    # The comma separated list of enabled resolutions
    enabled_resolutions: Optional[str] = None
    # The captions font family.
    font_family: Optional[str] = None
    # The GoogleWidevineDrm property
    google_widevine_drm: Optional[VideoLibrary_GoogleWidevineDrm] = None
    # Determines if the video library has a watermark configured
    has_watermark: Optional[bool] = None
    # The Id property
    id: Optional[int] = None
    # Determines if the original video files should be stored after encoding
    keep_original_files: Optional[bool] = None
    # The name of the Video Library.
    name: Optional[str] = None
    # The key color of the player.
    player_key_color: Optional[str] = None
    # Determines if the player token authentication is enabled
    player_token_authentication_enabled: Optional[bool] = None
    # The ID of the connected underlying pull zone
    pull_zone_id: Optional[int] = None
    # The PullZoneType property
    pull_zone_type: Optional[float] = None
    # The read-only API key used for authenticating with the video library
    read_only_api_key: Optional[str] = None
    # The list of languages that the captions will be automatically transcribed to.
    remember_player_position: Optional[bool] = None
    # The geo-replication regions of the underlying storage zone
    replication_regions: Optional[List[ReplicationRegions]] = None
    # Determines if the video watch heatmap should be displayed in the player.
    show_heatmap: Optional[bool] = None
    # The total amount of storage used by the library
    storage_usage: Optional[int] = None
    # The ID of the connected underlying storage zone
    storage_zone_id: Optional[int] = None
    # The amount of traffic usage this month
    traffic_usage: Optional[int] = None
    # The TranscribingCaptionLanguages property
    transcribing_caption_languages: Optional[List[str]] = None
    # The UI language of the player
    u_i_language: Optional[str] = None
    # The URL of the VAST tag endpoint for advertising configuration
    vast_tag_url: Optional[str] = None
    # The vi.ai publisher id for advertising configuration
    vi_ai_publisher_id: Optional[str] = None
    # The number of videos in the video library
    video_count: Optional[int] = None
    # The height of the watermark (in %)
    watermark_height: Optional[int] = None
    # The left offset of the watermark position (in %)
    watermark_position_left: Optional[int] = None
    # The top offset of the watermark position (in %)
    watermark_position_top: Optional[int] = None
    # The WatermarkVersion property
    watermark_version: Optional[int] = None
    # The width of the watermark (in %)
    watermark_width: Optional[int] = None
    # The webhook URL of the video library
    webhook_url: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> VideoLibrary:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: VideoLibrary
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return VideoLibrary()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .replication_regions import ReplicationRegions
        from .video_library_apple_fair_play_drm import VideoLibrary_AppleFairPlayDrm
        from .video_library_google_widevine_drm import VideoLibrary_GoogleWidevineDrm

        from .replication_regions import ReplicationRegions
        from .video_library_apple_fair_play_drm import VideoLibrary_AppleFairPlayDrm
        from .video_library_google_widevine_drm import VideoLibrary_GoogleWidevineDrm

        fields: Dict[str, Callable[[Any], None]] = {
            "AllowDirectPlay": lambda n : setattr(self, 'allow_direct_play', n.get_bool_value()),
            "AllowEarlyPlay": lambda n : setattr(self, 'allow_early_play', n.get_bool_value()),
            "AllowedReferrers": lambda n : setattr(self, 'allowed_referrers', n.get_collection_of_primitive_values(str)),
            "ApiAccessKey": lambda n : setattr(self, 'api_access_key', n.get_str_value()),
            "ApiKey": lambda n : setattr(self, 'api_key', n.get_str_value()),
            "AppleFairPlayDrm": lambda n : setattr(self, 'apple_fair_play_drm', n.get_object_value(VideoLibrary_AppleFairPlayDrm)),
            "Bitrate1080p": lambda n : setattr(self, 'bitrate1080p', n.get_int_value()),
            "Bitrate1440p": lambda n : setattr(self, 'bitrate1440p', n.get_int_value()),
            "Bitrate2160p": lambda n : setattr(self, 'bitrate2160p', n.get_int_value()),
            "Bitrate240p": lambda n : setattr(self, 'bitrate240p', n.get_int_value()),
            "Bitrate360p": lambda n : setattr(self, 'bitrate360p', n.get_int_value()),
            "Bitrate480p": lambda n : setattr(self, 'bitrate480p', n.get_int_value()),
            "Bitrate720p": lambda n : setattr(self, 'bitrate720p', n.get_int_value()),
            "BlockNoneReferrer": lambda n : setattr(self, 'block_none_referrer', n.get_bool_value()),
            "BlockedReferrers": lambda n : setattr(self, 'blocked_referrers', n.get_collection_of_primitive_values(str)),
            "CaptionsBackground": lambda n : setattr(self, 'captions_background', n.get_str_value()),
            "CaptionsFontColor": lambda n : setattr(self, 'captions_font_color', n.get_str_value()),
            "CaptionsFontSize": lambda n : setattr(self, 'captions_font_size', n.get_int_value()),
            "Controls": lambda n : setattr(self, 'controls', n.get_str_value()),
            "CustomHTML": lambda n : setattr(self, 'custom_h_t_m_l', n.get_str_value()),
            "DateCreated": lambda n : setattr(self, 'date_created', n.get_datetime_value()),
            "DrmVersion": lambda n : setattr(self, 'drm_version', n.get_int_value()),
            "EnableContentTagging": lambda n : setattr(self, 'enable_content_tagging', n.get_bool_value()),
            "EnableDRM": lambda n : setattr(self, 'enable_d_r_m', n.get_bool_value()),
            "EnableMP4Fallback": lambda n : setattr(self, 'enable_m_p4_fallback', n.get_bool_value()),
            "EnableTranscribing": lambda n : setattr(self, 'enable_transcribing', n.get_bool_value()),
            "EnableTranscribingDescriptionGeneration": lambda n : setattr(self, 'enable_transcribing_description_generation', n.get_bool_value()),
            "EnableTranscribingTitleGeneration": lambda n : setattr(self, 'enable_transcribing_title_generation', n.get_bool_value()),
            "EnabledResolutions": lambda n : setattr(self, 'enabled_resolutions', n.get_str_value()),
            "FontFamily": lambda n : setattr(self, 'font_family', n.get_str_value()),
            "GoogleWidevineDrm": lambda n : setattr(self, 'google_widevine_drm', n.get_object_value(VideoLibrary_GoogleWidevineDrm)),
            "HasWatermark": lambda n : setattr(self, 'has_watermark', n.get_bool_value()),
            "Id": lambda n : setattr(self, 'id', n.get_int_value()),
            "KeepOriginalFiles": lambda n : setattr(self, 'keep_original_files', n.get_bool_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "PlayerKeyColor": lambda n : setattr(self, 'player_key_color', n.get_str_value()),
            "PlayerTokenAuthenticationEnabled": lambda n : setattr(self, 'player_token_authentication_enabled', n.get_bool_value()),
            "PullZoneId": lambda n : setattr(self, 'pull_zone_id', n.get_int_value()),
            "PullZoneType": lambda n : setattr(self, 'pull_zone_type', n.get_float_value()),
            "ReadOnlyApiKey": lambda n : setattr(self, 'read_only_api_key', n.get_str_value()),
            "RememberPlayerPosition": lambda n : setattr(self, 'remember_player_position', n.get_bool_value()),
            "ReplicationRegions": lambda n : setattr(self, 'replication_regions', n.get_collection_of_enum_values(ReplicationRegions)),
            "ShowHeatmap": lambda n : setattr(self, 'show_heatmap', n.get_bool_value()),
            "StorageUsage": lambda n : setattr(self, 'storage_usage', n.get_int_value()),
            "StorageZoneId": lambda n : setattr(self, 'storage_zone_id', n.get_int_value()),
            "TrafficUsage": lambda n : setattr(self, 'traffic_usage', n.get_int_value()),
            "TranscribingCaptionLanguages": lambda n : setattr(self, 'transcribing_caption_languages', n.get_collection_of_primitive_values(str)),
            "UILanguage": lambda n : setattr(self, 'u_i_language', n.get_str_value()),
            "VastTagUrl": lambda n : setattr(self, 'vast_tag_url', n.get_str_value()),
            "ViAiPublisherId": lambda n : setattr(self, 'vi_ai_publisher_id', n.get_str_value()),
            "VideoCount": lambda n : setattr(self, 'video_count', n.get_int_value()),
            "WatermarkHeight": lambda n : setattr(self, 'watermark_height', n.get_int_value()),
            "WatermarkPositionLeft": lambda n : setattr(self, 'watermark_position_left', n.get_int_value()),
            "WatermarkPositionTop": lambda n : setattr(self, 'watermark_position_top', n.get_int_value()),
            "WatermarkVersion": lambda n : setattr(self, 'watermark_version', n.get_int_value()),
            "WatermarkWidth": lambda n : setattr(self, 'watermark_width', n.get_int_value()),
            "WebhookUrl": lambda n : setattr(self, 'webhook_url', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("AllowDirectPlay", self.allow_direct_play)
        writer.write_bool_value("AllowEarlyPlay", self.allow_early_play)
        writer.write_int_value("Bitrate1080p", self.bitrate1080p)
        writer.write_int_value("Bitrate1440p", self.bitrate1440p)
        writer.write_int_value("Bitrate2160p", self.bitrate2160p)
        writer.write_int_value("Bitrate240p", self.bitrate240p)
        writer.write_int_value("Bitrate360p", self.bitrate360p)
        writer.write_int_value("Bitrate480p", self.bitrate480p)
        writer.write_int_value("Bitrate720p", self.bitrate720p)
        writer.write_bool_value("BlockNoneReferrer", self.block_none_referrer)
        writer.write_str_value("CaptionsBackground", self.captions_background)
        writer.write_str_value("CaptionsFontColor", self.captions_font_color)
        writer.write_int_value("CaptionsFontSize", self.captions_font_size)
        writer.write_str_value("Controls", self.controls)
        writer.write_str_value("CustomHTML", self.custom_h_t_m_l)
        writer.write_bool_value("EnableContentTagging", self.enable_content_tagging)
        writer.write_bool_value("EnableDRM", self.enable_d_r_m)
        writer.write_bool_value("EnableMP4Fallback", self.enable_m_p4_fallback)
        writer.write_bool_value("EnableTranscribing", self.enable_transcribing)
        writer.write_bool_value("EnableTranscribingDescriptionGeneration", self.enable_transcribing_description_generation)
        writer.write_bool_value("EnableTranscribingTitleGeneration", self.enable_transcribing_title_generation)
        writer.write_str_value("EnabledResolutions", self.enabled_resolutions)
        writer.write_str_value("FontFamily", self.font_family)
        writer.write_bool_value("KeepOriginalFiles", self.keep_original_files)
        writer.write_str_value("Name", self.name)
        writer.write_str_value("PlayerKeyColor", self.player_key_color)
        writer.write_bool_value("PlayerTokenAuthenticationEnabled", self.player_token_authentication_enabled)
        writer.write_bool_value("ShowHeatmap", self.show_heatmap)
        writer.write_collection_of_primitive_values("TranscribingCaptionLanguages", self.transcribing_caption_languages)
        writer.write_str_value("UILanguage", self.u_i_language)
        writer.write_str_value("VastTagUrl", self.vast_tag_url)
        writer.write_str_value("ViAiPublisherId", self.vi_ai_publisher_id)
        writer.write_int_value("WatermarkHeight", self.watermark_height)
        writer.write_int_value("WatermarkPositionLeft", self.watermark_position_left)
        writer.write_int_value("WatermarkPositionTop", self.watermark_position_top)
        writer.write_int_value("WatermarkWidth", self.watermark_width)
        writer.write_str_value("WebhookUrl", self.webhook_url)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .bunny_ai_image_blueprint import BunnyAiImageBlueprint
    from .edge_rule.edge_rule import EdgeRule
    from .hostname import Hostname
    from .optimizer.optimizer_class import OptimizerClass
    from .pull_zone_routing_filters import PullZone_RoutingFilters

@dataclass
class PullZone(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # Determines if the AWS Signing is enabled
    a_w_s_signing_enabled: Optional[bool] = None
    # The AWS Signing region key
    a_w_s_signing_key: Optional[str] = None
    # The AWS Signing region name
    a_w_s_signing_region_name: Optional[str] = None
    # The AWS Signing region secret
    a_w_s_signing_secret: Optional[str] = None
    # The list of extensions that will return the CORS headers
    access_control_origin_header_extensions: Optional[List[str]] = None
    # Determines if the Add Canonical Header is enabled for this Pull Zone
    add_canonical_header: Optional[bool] = None
    # Determines if the Pull Zone should forward the current hostname to the origin
    add_host_header: Optional[bool] = None
    # The Pull Zone specific pricing discount for Africa region.
    africa_discount: Optional[int] = None
    # The list of referrer hostnames that are allowed to access the pull zone.Requests containing the header Referer: hostname that is not on the list will be rejected.If empty, all the referrers are allowed
    allowed_referrers: Optional[List[str]] = None
    # The Pull Zone specific pricing discount for Asia & Oceania region.
    asia_oceania_discount: Optional[int] = None
    # The BlockNoneReferrer property
    block_none_referrer: Optional[bool] = None
    # If true, POST requests to the zone will be blocked
    block_post_requests: Optional[bool] = None
    # If true, access to root path will return a 403 error
    block_root_path_access: Optional[bool] = None
    # The list of blocked countries with the two-letter Alpha2 ISO codes
    blocked_countries: Optional[List[str]] = None
    # The list of IPs that are blocked from accessing the pull zone. Requests coming from the following IPs will be rejected. If empty, all the IPs will be allowed
    blocked_ips: Optional[List[str]] = None
    # The list of referrer hostnames that are not allowed to access the pull zone. Requests containing the header Referer: hostname that is on the list will be rejected. If empty, all the referrers are allowed
    blocked_referrers: Optional[List[str]] = None
    # The list of budget redirected countries with the two-letter Alpha2 ISO codes
    budget_redirected_countries: Optional[List[str]] = None
    # The BunnyAiImageBlueprints property
    bunny_ai_image_blueprints: Optional[List[BunnyAiImageBlueprint]] = None
    # Excessive requests are delayed until their number exceeds the maximum burst size.
    burst_size: Optional[int] = None
    # The override cache time for the pull zone
    cache_control_max_age_override: Optional[int] = None
    # The override cache time for the pull zone for the end client
    cache_control_public_max_age_override: Optional[int] = None
    # Determines if bunny.net should be caching error responses
    cache_error_responses: Optional[bool] = None
    # The CacheVersion property
    cache_version: Optional[float] = None
    # The CNAME domain of the pull zone for setting up custom hostnames
    cname_domain: Optional[str] = None
    # The number of connections limited per IP for this zone
    connection_limit_per_i_p_count: Optional[int] = None
    # Contains the list of vary parameters that will be used for vary cache by cookie string. If empty, cookie vary will not be used.
    cookie_vary_parameters: Optional[List[str]] = None
    # Determines if the cookies are disabled for the pull zone
    disable_cookies: Optional[bool] = None
    # If true, the built-in let's encrypt is disabled and requests are passed to the origin.
    disable_lets_encrypt: Optional[bool] = None
    # The ID of the DNS record tied to this pull zone
    dns_record_id: Optional[int] = None
    # The cached version of the DNS record value
    dns_record_value: Optional[str] = None
    # The ID of the DNS zone tied to this pull zone
    dns_zone_id: Optional[int] = None
    # The Pull Zone specific pricing discount for EU and US region.
    e_u_u_s_discount: Optional[int] = None
    # The list of edge rules on this Pull Zone
    edge_rules: Optional[List[EdgeRule]] = None
    # The EdgeScriptExecutionPhase property
    edge_script_execution_phase: Optional[float] = None
    # The ID of the edge script that the pull zone is linked to
    edge_script_id: Optional[int] = None
    # Determines if the CORS headers should be enabled
    enable_access_control_origin_header: Optional[bool] = None
    # If set to true, any hostnames added to this Pull Zone will automatically enable SSL.
    enable_auto_s_s_l: Optional[bool] = None
    # Determines if the AVIF Vary feature is enabled.
    enable_avif_vary: Optional[bool] = None
    # The EnableBunnyImageAi property
    enable_bunny_image_ai: Optional[bool] = None
    # Determines if the cache slice (Optimize for video) feature is enabled for the Pull Zone
    enable_cache_slice: Optional[bool] = None
    # Determines if the Cookie Vary feature is enabled.
    enable_cookie_vary: Optional[bool] = None
    # Determines if the Country Code Vary feature is enabled.
    enable_country_code_vary: Optional[bool] = None
    # Determines if the delivery from the Africa region is enabled for this pull zone
    enable_geo_zone_a_f: Optional[bool] = None
    # Determines if the delivery from the Asian / Oceanian region is enabled for this pull zone
    enable_geo_zone_a_s_i_a: Optional[bool] = None
    # Determines if the delivery from the European region is enabled for this pull zone
    enable_geo_zone_e_u: Optional[bool] = None
    # Determines if the delivery from the South American region is enabled for this pull zone
    enable_geo_zone_s_a: Optional[bool] = None
    # Determines if the delivery from the North American region is enabled for this pull zone
    enable_geo_zone_u_s: Optional[bool] = None
    # Determines if the Hostname Vary feature is enabled.
    enable_hostname_vary: Optional[bool] = None
    # Determines if the logging is enabled for this Pull Zone
    enable_logging: Optional[bool] = None
    # Determines if the Mobile Vary feature is enabled.
    enable_mobile_vary: Optional[bool] = None
    # If true the server will use the origin shield feature
    enable_origin_shield: Optional[bool] = None
    # If set to true the query string ordering property is enabled.
    enable_query_string_ordering: Optional[bool] = None
    # Determines if request coalescing is currently enabled.
    enable_request_coalescing: Optional[bool] = None
    # The EnableSafeHop property
    enable_safe_hop: Optional[bool] = None
    # Determines if smart caching is enabled for this zone
    enable_smart_cache: Optional[bool] = None
    # Determines if the TLS 1 is enabled on the Pull Zone
    enable_t_l_s1: Optional[bool] = None
    # Determines if the TLS 1.1 is enabled on the Pull Zone
    enable_t_l_s1_1: Optional[bool] = None
    # Determines if the WebP Vary feature is enabled.
    enable_web_p_vary: Optional[bool] = None
    # Determines if the Pull Zone is currently enabled, active and running
    enabled: Optional[bool] = None
    # Contains the custom error page code that will be returned
    error_page_custom_code: Optional[str] = None
    # Determines if custom error page code should be enabled.
    error_page_enable_custom_code: Optional[bool] = None
    # Determines if the statuspage widget should be displayed on the error pages
    error_page_enable_statuspage_widget: Optional[bool] = None
    # The statuspage code that will be used to build the status widget
    error_page_statuspage_code: Optional[str] = None
    # Determines if the error pages should be whitelabel or not
    error_page_whitelabel: Optional[bool] = None
    # Determines if the zone will follow origin redirects
    follow_redirects: Optional[bool] = None
    # The list of hostnames linked to this Pull Zone
    hostnames: Optional[List[Hostname]] = None
    # The unique ID of the pull zone.
    id: Optional[int] = None
    # True if the Pull Zone is ignoring query strings when serving cached objects
    ignore_query_strings: Optional[bool] = None
    # The amount of data after the rate limit will be activated
    limit_rate_after: Optional[float] = None
    # The maximum rate at which the zone will transfer data in kb/s. 0 for unlimited
    limit_rate_per_second: Optional[float] = None
    # The LogAnonymizationType property
    log_anonymization_type: Optional[float] = None
    # The LogFormat property
    log_format: Optional[float] = None
    # Determines if the log forwarding is enabled
    log_forwarding_enabled: Optional[bool] = None
    # The LogForwardingFormat property
    log_forwarding_format: Optional[float] = None
    # The log forwarding hostname
    log_forwarding_hostname: Optional[str] = None
    # The log forwarding port
    log_forwarding_port: Optional[int] = None
    # The LogForwardingProtocol property
    log_forwarding_protocol: Optional[float] = None
    # The log forwarding token value
    log_forwarding_token: Optional[str] = None
    # Determines if the log anonymization should be enabled
    logging_i_p_anonymization_enabled: Optional[bool] = None
    # Determines if the permanent logging feature is enabled
    logging_save_to_storage: Optional[bool] = None
    # The ID of the logging storage zone that is configured for this Pull Zone
    logging_storage_zone_id: Optional[int] = None
    # The MagicContainersAppId property
    magic_containers_app_id: Optional[str] = None
    # The MagicContainersEndpointId property
    magic_containers_endpoint_id: Optional[int] = None
    # The MiddlewareScriptId property
    middleware_script_id: Optional[int] = None
    # The monthly limit of bandwidth in bytes that the pullzone is allowed to use
    monthly_bandwidth_limit: Optional[int] = None
    # The amount of bandwidth in bytes that the pull zone used this month
    monthly_bandwidth_used: Optional[int] = None
    # The total monthly charges for this so zone so far
    monthly_charges: Optional[float] = None
    # The name of the pull zone.
    name: Optional[str] = None
    # Determines if the automatic image optimization should be enabled
    optimizer_automatic_optimization_enabled: Optional[bool] = None
    # Contains the list of optimizer classes
    optimizer_classes: Optional[List[OptimizerClass]] = None
    # Determines the maximum automatic image size for desktop clients
    optimizer_desktop_max_width: Optional[int] = None
    # Determines the image manipulation should be enabled
    optimizer_enable_manipulation_engine: Optional[bool] = None
    # Determines if the WebP optimization should be enabled
    optimizer_enable_web_p: Optional[bool] = None
    # Determines if the optimizer should be enabled for this zone
    optimizer_enabled: Optional[bool] = None
    # Determines if the optimizer class list should be enforced
    optimizer_force_classes: Optional[bool] = None
    # Determines the image quality for desktop clients
    optimizer_image_quality: Optional[int] = None
    # Determines if the CSS minification should be enabled
    optimizer_minify_c_s_s: Optional[bool] = None
    # Determines if the JavaScript minification should be enabled
    optimizer_minify_java_script: Optional[bool] = None
    # Determines the image quality for mobile clients
    optimizer_mobile_image_quality: Optional[int] = None
    # Determines the maximum automatic image size for mobile clients
    optimizer_mobile_max_width: Optional[int] = None
    # The OptimizerStaticHtmlEnabled property
    optimizer_static_html_enabled: Optional[bool] = None
    # The OptimizerStaticHtmlWordPressBypassCookie property
    optimizer_static_html_word_press_bypass_cookie: Optional[str] = None
    # The OptimizerStaticHtmlWordPressPath property
    optimizer_static_html_word_press_path: Optional[str] = None
    # Determines if image watermarking should be enabled
    optimizer_watermark_enabled: Optional[bool] = None
    # Sets the minimum image size to which the watermark will be added
    optimizer_watermark_min_image_size: Optional[int] = None
    # Sets the offset of the watermark image
    optimizer_watermark_offset: Optional[float] = None
    # The OptimizerWatermarkPosition property
    optimizer_watermark_position: Optional[float] = None
    # Sets the URL of the watermark image
    optimizer_watermark_url: Optional[str] = None
    # The amount of seconds to wait when connecting to the origin. Otherwise the request will fail or retry.
    origin_connect_timeout: Optional[int] = None
    # Determines the host header that will be sent to the origin
    origin_host_header: Optional[str] = None
    # Returns the link short preview value for the pull zone origin connection.
    origin_link_value: Optional[str] = None
    # The amount of seconds to wait when waiting for the origin reply. Otherwise the request will fail or retry.
    origin_response_timeout: Optional[int] = None
    # The number of retries to the origin server
    origin_retries: Optional[int] = None
    # Determines if we should retry the request in case of a connection timeout.
    origin_retry_connection_timeout: Optional[bool] = None
    # Determines the amount of time that the CDN should wait before retrying an origin request.
    origin_retry_delay: Optional[int] = None
    # Determines if we should retry the request in case of a response timeout.
    origin_retry_response_timeout: Optional[bool] = None
    # Determines if we should retry the request in case of a 5XX response.
    origin_retry5_x_x_responses: Optional[bool] = None
    # Determines if the origin shield concurrency limit is enabled.
    origin_shield_enable_concurrency_limit: Optional[bool] = None
    # Determines the number of maximum concurrent requests allowed to the origin.
    origin_shield_max_concurrent_requests: Optional[int] = None
    # Determines the max number of origin requests that will remain in the queue
    origin_shield_max_queued_requests: Optional[int] = None
    # Determines the max queue wait time
    origin_shield_queue_max_wait_time: Optional[int] = None
    # The zone code of the origin shield
    origin_shield_zone_code: Optional[str] = None
    # The OriginType property
    origin_type: Optional[float] = None
    # The origin URL of the pull zone where the files are fetched from.
    origin_url: Optional[str] = None
    # The IP of the storage zone used for Perma-Cache
    perma_cache_storage_zone_id: Optional[int] = None
    # The PermaCacheType property
    perma_cache_type: Optional[int] = None
    # The custom preloading screen code
    preloading_screen_code: Optional[str] = None
    # Determines if the custom preloader screen is enabled
    preloading_screen_code_enabled: Optional[bool] = None
    # The delay in milliseconds after which the preloading screen will be displayed
    preloading_screen_delay: Optional[int] = None
    # Determines if the preloading screen is currently enabled
    preloading_screen_enabled: Optional[bool] = None
    # The preloading screen logo URL
    preloading_screen_logo_url: Optional[str] = None
    # The PreloadingScreenShowOnFirstVisit property
    preloading_screen_show_on_first_visit: Optional[bool] = None
    # The PreloadingScreenTheme property
    preloading_screen_theme: Optional[float] = None
    # The custom price override for this zone
    price_override: Optional[float] = None
    # Contains the list of vary parameters that will be used for vary cache by query string. If empty, all parameters will be used to construct the key
    query_string_vary_parameters: Optional[List[str]] = None
    # Determines the lock time for coalesced requests.
    request_coalescing_timeout: Optional[int] = None
    # Max number of requests per IP per second
    request_limit: Optional[int] = None
    # The list of routing filters enabled for this zone
    routing_filters: Optional[List[PullZone_RoutingFilters]] = None
    # The ShieldDDosProtectionEnabled property
    shield_d_dos_protection_enabled: Optional[bool] = None
    # The ShieldDDosProtectionType property
    shield_d_dos_protection_type: Optional[float] = None
    # The Pull Zone specific pricing discount for South America region.
    south_america_discount: Optional[int] = None
    # The ID of the storage zone that the pull zone is linked to
    storage_zone_id: Optional[int] = None
    # The Suspended property
    suspended: Optional[bool] = None
    # The Type property
    type: Optional[float] = None
    # Determines if cache update is performed in the background.
    use_background_update: Optional[bool] = None
    # Determines if we should use stale cache while the origin is offline
    use_stale_while_offline: Optional[bool] = None
    # Determines if we should use stale cache while cache is updating
    use_stale_while_updating: Optional[bool] = None
    # The UserId property
    user_id: Optional[str] = None
    # Determines if the Pull Zone should verify the origin SSL certificate
    verify_origin_s_s_l: Optional[bool] = None
    # The ID of the video library that the zone is linked to
    video_library_id: Optional[int] = None
    # True if the URL secure token authentication security is enabled
    zone_security_enabled: Optional[bool] = None
    # True if the zone security hash should include the remote IP
    zone_security_include_hash_remote_i_p: Optional[bool] = None
    # The security key used for secure URL token authentication
    zone_security_key: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> PullZone:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: PullZone
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return PullZone()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .bunny_ai_image_blueprint import BunnyAiImageBlueprint
        from .edge_rule.edge_rule import EdgeRule
        from .hostname import Hostname
        from .optimizer.optimizer_class import OptimizerClass
        from .pull_zone_routing_filters import PullZone_RoutingFilters

        from .bunny_ai_image_blueprint import BunnyAiImageBlueprint
        from .edge_rule.edge_rule import EdgeRule
        from .hostname import Hostname
        from .optimizer.optimizer_class import OptimizerClass
        from .pull_zone_routing_filters import PullZone_RoutingFilters

        fields: Dict[str, Callable[[Any], None]] = {
            "AWSSigningEnabled": lambda n : setattr(self, 'a_w_s_signing_enabled', n.get_bool_value()),
            "AWSSigningKey": lambda n : setattr(self, 'a_w_s_signing_key', n.get_str_value()),
            "AWSSigningRegionName": lambda n : setattr(self, 'a_w_s_signing_region_name', n.get_str_value()),
            "AWSSigningSecret": lambda n : setattr(self, 'a_w_s_signing_secret', n.get_str_value()),
            "AccessControlOriginHeaderExtensions": lambda n : setattr(self, 'access_control_origin_header_extensions', n.get_collection_of_primitive_values(str)),
            "AddCanonicalHeader": lambda n : setattr(self, 'add_canonical_header', n.get_bool_value()),
            "AddHostHeader": lambda n : setattr(self, 'add_host_header', n.get_bool_value()),
            "AfricaDiscount": lambda n : setattr(self, 'africa_discount', n.get_int_value()),
            "AllowedReferrers": lambda n : setattr(self, 'allowed_referrers', n.get_collection_of_primitive_values(str)),
            "AsiaOceaniaDiscount": lambda n : setattr(self, 'asia_oceania_discount', n.get_int_value()),
            "BlockNoneReferrer": lambda n : setattr(self, 'block_none_referrer', n.get_bool_value()),
            "BlockPostRequests": lambda n : setattr(self, 'block_post_requests', n.get_bool_value()),
            "BlockRootPathAccess": lambda n : setattr(self, 'block_root_path_access', n.get_bool_value()),
            "BlockedCountries": lambda n : setattr(self, 'blocked_countries', n.get_collection_of_primitive_values(str)),
            "BlockedIps": lambda n : setattr(self, 'blocked_ips', n.get_collection_of_primitive_values(str)),
            "BlockedReferrers": lambda n : setattr(self, 'blocked_referrers', n.get_collection_of_primitive_values(str)),
            "BudgetRedirectedCountries": lambda n : setattr(self, 'budget_redirected_countries', n.get_collection_of_primitive_values(str)),
            "BunnyAiImageBlueprints": lambda n : setattr(self, 'bunny_ai_image_blueprints', n.get_collection_of_object_values(BunnyAiImageBlueprint)),
            "BurstSize": lambda n : setattr(self, 'burst_size', n.get_int_value()),
            "CacheControlMaxAgeOverride": lambda n : setattr(self, 'cache_control_max_age_override', n.get_int_value()),
            "CacheControlPublicMaxAgeOverride": lambda n : setattr(self, 'cache_control_public_max_age_override', n.get_int_value()),
            "CacheErrorResponses": lambda n : setattr(self, 'cache_error_responses', n.get_bool_value()),
            "CacheVersion": lambda n : setattr(self, 'cache_version', n.get_float_value()),
            "CnameDomain": lambda n : setattr(self, 'cname_domain', n.get_str_value()),
            "ConnectionLimitPerIPCount": lambda n : setattr(self, 'connection_limit_per_i_p_count', n.get_int_value()),
            "CookieVaryParameters": lambda n : setattr(self, 'cookie_vary_parameters', n.get_collection_of_primitive_values(str)),
            "DisableCookies": lambda n : setattr(self, 'disable_cookies', n.get_bool_value()),
            "DisableLetsEncrypt": lambda n : setattr(self, 'disable_lets_encrypt', n.get_bool_value()),
            "DnsRecordId": lambda n : setattr(self, 'dns_record_id', n.get_int_value()),
            "DnsRecordValue": lambda n : setattr(self, 'dns_record_value', n.get_str_value()),
            "DnsZoneId": lambda n : setattr(self, 'dns_zone_id', n.get_int_value()),
            "EUUSDiscount": lambda n : setattr(self, 'e_u_u_s_discount', n.get_int_value()),
            "EdgeRules": lambda n : setattr(self, 'edge_rules', n.get_collection_of_object_values(EdgeRule)),
            "EdgeScriptExecutionPhase": lambda n : setattr(self, 'edge_script_execution_phase', n.get_float_value()),
            "EdgeScriptId": lambda n : setattr(self, 'edge_script_id', n.get_int_value()),
            "EnableAccessControlOriginHeader": lambda n : setattr(self, 'enable_access_control_origin_header', n.get_bool_value()),
            "EnableAutoSSL": lambda n : setattr(self, 'enable_auto_s_s_l', n.get_bool_value()),
            "EnableAvifVary": lambda n : setattr(self, 'enable_avif_vary', n.get_bool_value()),
            "EnableBunnyImageAi": lambda n : setattr(self, 'enable_bunny_image_ai', n.get_bool_value()),
            "EnableCacheSlice": lambda n : setattr(self, 'enable_cache_slice', n.get_bool_value()),
            "EnableCookieVary": lambda n : setattr(self, 'enable_cookie_vary', n.get_bool_value()),
            "EnableCountryCodeVary": lambda n : setattr(self, 'enable_country_code_vary', n.get_bool_value()),
            "EnableGeoZoneAF": lambda n : setattr(self, 'enable_geo_zone_a_f', n.get_bool_value()),
            "EnableGeoZoneASIA": lambda n : setattr(self, 'enable_geo_zone_a_s_i_a', n.get_bool_value()),
            "EnableGeoZoneEU": lambda n : setattr(self, 'enable_geo_zone_e_u', n.get_bool_value()),
            "EnableGeoZoneSA": lambda n : setattr(self, 'enable_geo_zone_s_a', n.get_bool_value()),
            "EnableGeoZoneUS": lambda n : setattr(self, 'enable_geo_zone_u_s', n.get_bool_value()),
            "EnableHostnameVary": lambda n : setattr(self, 'enable_hostname_vary', n.get_bool_value()),
            "EnableLogging": lambda n : setattr(self, 'enable_logging', n.get_bool_value()),
            "EnableMobileVary": lambda n : setattr(self, 'enable_mobile_vary', n.get_bool_value()),
            "EnableOriginShield": lambda n : setattr(self, 'enable_origin_shield', n.get_bool_value()),
            "EnableQueryStringOrdering": lambda n : setattr(self, 'enable_query_string_ordering', n.get_bool_value()),
            "EnableRequestCoalescing": lambda n : setattr(self, 'enable_request_coalescing', n.get_bool_value()),
            "EnableSafeHop": lambda n : setattr(self, 'enable_safe_hop', n.get_bool_value()),
            "EnableSmartCache": lambda n : setattr(self, 'enable_smart_cache', n.get_bool_value()),
            "EnableTLS1": lambda n : setattr(self, 'enable_t_l_s1', n.get_bool_value()),
            "EnableTLS1_1": lambda n : setattr(self, 'enable_t_l_s1_1', n.get_bool_value()),
            "EnableWebPVary": lambda n : setattr(self, 'enable_web_p_vary', n.get_bool_value()),
            "Enabled": lambda n : setattr(self, 'enabled', n.get_bool_value()),
            "ErrorPageCustomCode": lambda n : setattr(self, 'error_page_custom_code', n.get_str_value()),
            "ErrorPageEnableCustomCode": lambda n : setattr(self, 'error_page_enable_custom_code', n.get_bool_value()),
            "ErrorPageEnableStatuspageWidget": lambda n : setattr(self, 'error_page_enable_statuspage_widget', n.get_bool_value()),
            "ErrorPageStatuspageCode": lambda n : setattr(self, 'error_page_statuspage_code', n.get_str_value()),
            "ErrorPageWhitelabel": lambda n : setattr(self, 'error_page_whitelabel', n.get_bool_value()),
            "FollowRedirects": lambda n : setattr(self, 'follow_redirects', n.get_bool_value()),
            "Hostnames": lambda n : setattr(self, 'hostnames', n.get_collection_of_object_values(Hostname)),
            "Id": lambda n : setattr(self, 'id', n.get_int_value()),
            "IgnoreQueryStrings": lambda n : setattr(self, 'ignore_query_strings', n.get_bool_value()),
            "LimitRateAfter": lambda n : setattr(self, 'limit_rate_after', n.get_float_value()),
            "LimitRatePerSecond": lambda n : setattr(self, 'limit_rate_per_second', n.get_float_value()),
            "LogAnonymizationType": lambda n : setattr(self, 'log_anonymization_type', n.get_float_value()),
            "LogFormat": lambda n : setattr(self, 'log_format', n.get_float_value()),
            "LogForwardingEnabled": lambda n : setattr(self, 'log_forwarding_enabled', n.get_bool_value()),
            "LogForwardingFormat": lambda n : setattr(self, 'log_forwarding_format', n.get_float_value()),
            "LogForwardingHostname": lambda n : setattr(self, 'log_forwarding_hostname', n.get_str_value()),
            "LogForwardingPort": lambda n : setattr(self, 'log_forwarding_port', n.get_int_value()),
            "LogForwardingProtocol": lambda n : setattr(self, 'log_forwarding_protocol', n.get_float_value()),
            "LogForwardingToken": lambda n : setattr(self, 'log_forwarding_token', n.get_str_value()),
            "LoggingIPAnonymizationEnabled": lambda n : setattr(self, 'logging_i_p_anonymization_enabled', n.get_bool_value()),
            "LoggingSaveToStorage": lambda n : setattr(self, 'logging_save_to_storage', n.get_bool_value()),
            "LoggingStorageZoneId": lambda n : setattr(self, 'logging_storage_zone_id', n.get_int_value()),
            "MagicContainersAppId": lambda n : setattr(self, 'magic_containers_app_id', n.get_str_value()),
            "MagicContainersEndpointId": lambda n : setattr(self, 'magic_containers_endpoint_id', n.get_int_value()),
            "MiddlewareScriptId": lambda n : setattr(self, 'middleware_script_id', n.get_int_value()),
            "MonthlyBandwidthLimit": lambda n : setattr(self, 'monthly_bandwidth_limit', n.get_int_value()),
            "MonthlyBandwidthUsed": lambda n : setattr(self, 'monthly_bandwidth_used', n.get_int_value()),
            "MonthlyCharges": lambda n : setattr(self, 'monthly_charges', n.get_float_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "OptimizerAutomaticOptimizationEnabled": lambda n : setattr(self, 'optimizer_automatic_optimization_enabled', n.get_bool_value()),
            "OptimizerClasses": lambda n : setattr(self, 'optimizer_classes', n.get_collection_of_object_values(OptimizerClass)),
            "OptimizerDesktopMaxWidth": lambda n : setattr(self, 'optimizer_desktop_max_width', n.get_int_value()),
            "OptimizerEnableManipulationEngine": lambda n : setattr(self, 'optimizer_enable_manipulation_engine', n.get_bool_value()),
            "OptimizerEnableWebP": lambda n : setattr(self, 'optimizer_enable_web_p', n.get_bool_value()),
            "OptimizerEnabled": lambda n : setattr(self, 'optimizer_enabled', n.get_bool_value()),
            "OptimizerForceClasses": lambda n : setattr(self, 'optimizer_force_classes', n.get_bool_value()),
            "OptimizerImageQuality": lambda n : setattr(self, 'optimizer_image_quality', n.get_int_value()),
            "OptimizerMinifyCSS": lambda n : setattr(self, 'optimizer_minify_c_s_s', n.get_bool_value()),
            "OptimizerMinifyJavaScript": lambda n : setattr(self, 'optimizer_minify_java_script', n.get_bool_value()),
            "OptimizerMobileImageQuality": lambda n : setattr(self, 'optimizer_mobile_image_quality', n.get_int_value()),
            "OptimizerMobileMaxWidth": lambda n : setattr(self, 'optimizer_mobile_max_width', n.get_int_value()),
            "OptimizerStaticHtmlEnabled": lambda n : setattr(self, 'optimizer_static_html_enabled', n.get_bool_value()),
            "OptimizerStaticHtmlWordPressBypassCookie": lambda n : setattr(self, 'optimizer_static_html_word_press_bypass_cookie', n.get_str_value()),
            "OptimizerStaticHtmlWordPressPath": lambda n : setattr(self, 'optimizer_static_html_word_press_path', n.get_str_value()),
            "OptimizerWatermarkEnabled": lambda n : setattr(self, 'optimizer_watermark_enabled', n.get_bool_value()),
            "OptimizerWatermarkMinImageSize": lambda n : setattr(self, 'optimizer_watermark_min_image_size', n.get_int_value()),
            "OptimizerWatermarkOffset": lambda n : setattr(self, 'optimizer_watermark_offset', n.get_float_value()),
            "OptimizerWatermarkPosition": lambda n : setattr(self, 'optimizer_watermark_position', n.get_float_value()),
            "OptimizerWatermarkUrl": lambda n : setattr(self, 'optimizer_watermark_url', n.get_str_value()),
            "OriginConnectTimeout": lambda n : setattr(self, 'origin_connect_timeout', n.get_int_value()),
            "OriginHostHeader": lambda n : setattr(self, 'origin_host_header', n.get_str_value()),
            "OriginLinkValue": lambda n : setattr(self, 'origin_link_value', n.get_str_value()),
            "OriginResponseTimeout": lambda n : setattr(self, 'origin_response_timeout', n.get_int_value()),
            "OriginRetries": lambda n : setattr(self, 'origin_retries', n.get_int_value()),
            "OriginRetryConnectionTimeout": lambda n : setattr(self, 'origin_retry_connection_timeout', n.get_bool_value()),
            "OriginRetryDelay": lambda n : setattr(self, 'origin_retry_delay', n.get_int_value()),
            "OriginRetryResponseTimeout": lambda n : setattr(self, 'origin_retry_response_timeout', n.get_bool_value()),
            "OriginRetry5XXResponses": lambda n : setattr(self, 'origin_retry5_x_x_responses', n.get_bool_value()),
            "OriginShieldEnableConcurrencyLimit": lambda n : setattr(self, 'origin_shield_enable_concurrency_limit', n.get_bool_value()),
            "OriginShieldMaxConcurrentRequests": lambda n : setattr(self, 'origin_shield_max_concurrent_requests', n.get_int_value()),
            "OriginShieldMaxQueuedRequests": lambda n : setattr(self, 'origin_shield_max_queued_requests', n.get_int_value()),
            "OriginShieldQueueMaxWaitTime": lambda n : setattr(self, 'origin_shield_queue_max_wait_time', n.get_int_value()),
            "OriginShieldZoneCode": lambda n : setattr(self, 'origin_shield_zone_code', n.get_str_value()),
            "OriginType": lambda n : setattr(self, 'origin_type', n.get_float_value()),
            "OriginUrl": lambda n : setattr(self, 'origin_url', n.get_str_value()),
            "PermaCacheStorageZoneId": lambda n : setattr(self, 'perma_cache_storage_zone_id', n.get_int_value()),
            "PermaCacheType": lambda n : setattr(self, 'perma_cache_type', n.get_int_value()),
            "PreloadingScreenCode": lambda n : setattr(self, 'preloading_screen_code', n.get_str_value()),
            "PreloadingScreenCodeEnabled": lambda n : setattr(self, 'preloading_screen_code_enabled', n.get_bool_value()),
            "PreloadingScreenDelay": lambda n : setattr(self, 'preloading_screen_delay', n.get_int_value()),
            "PreloadingScreenEnabled": lambda n : setattr(self, 'preloading_screen_enabled', n.get_bool_value()),
            "PreloadingScreenLogoUrl": lambda n : setattr(self, 'preloading_screen_logo_url', n.get_str_value()),
            "PreloadingScreenShowOnFirstVisit": lambda n : setattr(self, 'preloading_screen_show_on_first_visit', n.get_bool_value()),
            "PreloadingScreenTheme": lambda n : setattr(self, 'preloading_screen_theme', n.get_float_value()),
            "PriceOverride": lambda n : setattr(self, 'price_override', n.get_float_value()),
            "QueryStringVaryParameters": lambda n : setattr(self, 'query_string_vary_parameters', n.get_collection_of_primitive_values(str)),
            "RequestCoalescingTimeout": lambda n : setattr(self, 'request_coalescing_timeout', n.get_int_value()),
            "RequestLimit": lambda n : setattr(self, 'request_limit', n.get_int_value()),
            "RoutingFilters": lambda n : setattr(self, 'routing_filters', n.get_collection_of_enum_values(PullZone_RoutingFilters)),
            "ShieldDDosProtectionEnabled": lambda n : setattr(self, 'shield_d_dos_protection_enabled', n.get_bool_value()),
            "ShieldDDosProtectionType": lambda n : setattr(self, 'shield_d_dos_protection_type', n.get_float_value()),
            "SouthAmericaDiscount": lambda n : setattr(self, 'south_america_discount', n.get_int_value()),
            "StorageZoneId": lambda n : setattr(self, 'storage_zone_id', n.get_int_value()),
            "Suspended": lambda n : setattr(self, 'suspended', n.get_bool_value()),
            "Type": lambda n : setattr(self, 'type', n.get_float_value()),
            "UseBackgroundUpdate": lambda n : setattr(self, 'use_background_update', n.get_bool_value()),
            "UseStaleWhileOffline": lambda n : setattr(self, 'use_stale_while_offline', n.get_bool_value()),
            "UseStaleWhileUpdating": lambda n : setattr(self, 'use_stale_while_updating', n.get_bool_value()),
            "UserId": lambda n : setattr(self, 'user_id', n.get_str_value()),
            "VerifyOriginSSL": lambda n : setattr(self, 'verify_origin_s_s_l', n.get_bool_value()),
            "VideoLibraryId": lambda n : setattr(self, 'video_library_id', n.get_int_value()),
            "ZoneSecurityEnabled": lambda n : setattr(self, 'zone_security_enabled', n.get_bool_value()),
            "ZoneSecurityIncludeHashRemoteIP": lambda n : setattr(self, 'zone_security_include_hash_remote_i_p', n.get_bool_value()),
            "ZoneSecurityKey": lambda n : setattr(self, 'zone_security_key', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("AWSSigningEnabled", self.a_w_s_signing_enabled)
        writer.write_str_value("AWSSigningKey", self.a_w_s_signing_key)
        writer.write_str_value("AWSSigningRegionName", self.a_w_s_signing_region_name)
        writer.write_str_value("AWSSigningSecret", self.a_w_s_signing_secret)
        writer.write_collection_of_primitive_values("AccessControlOriginHeaderExtensions", self.access_control_origin_header_extensions)
        writer.write_bool_value("AddCanonicalHeader", self.add_canonical_header)
        writer.write_bool_value("AddHostHeader", self.add_host_header)
        writer.write_collection_of_primitive_values("AllowedReferrers", self.allowed_referrers)
        writer.write_bool_value("BlockNoneReferrer", self.block_none_referrer)
        writer.write_bool_value("BlockPostRequests", self.block_post_requests)
        writer.write_bool_value("BlockRootPathAccess", self.block_root_path_access)
        writer.write_collection_of_primitive_values("BlockedCountries", self.blocked_countries)
        writer.write_collection_of_primitive_values("BlockedIps", self.blocked_ips)
        writer.write_collection_of_primitive_values("BlockedReferrers", self.blocked_referrers)
        writer.write_collection_of_primitive_values("BudgetRedirectedCountries", self.budget_redirected_countries)
        writer.write_collection_of_object_values("BunnyAiImageBlueprints", self.bunny_ai_image_blueprints)
        writer.write_int_value("BurstSize", self.burst_size)
        writer.write_int_value("CacheControlMaxAgeOverride", self.cache_control_max_age_override)
        writer.write_int_value("CacheControlPublicMaxAgeOverride", self.cache_control_public_max_age_override)
        writer.write_bool_value("CacheErrorResponses", self.cache_error_responses)
        writer.write_int_value("ConnectionLimitPerIPCount", self.connection_limit_per_i_p_count)
        writer.write_collection_of_primitive_values("CookieVaryParameters", self.cookie_vary_parameters)
        writer.write_bool_value("DisableCookies", self.disable_cookies)
        writer.write_bool_value("DisableLetsEncrypt", self.disable_lets_encrypt)
        writer.write_collection_of_object_values("EdgeRules", self.edge_rules)
        writer.write_float_value("EdgeScriptExecutionPhase", self.edge_script_execution_phase)
        writer.write_int_value("EdgeScriptId", self.edge_script_id)
        writer.write_bool_value("EnableAccessControlOriginHeader", self.enable_access_control_origin_header)
        writer.write_bool_value("EnableAutoSSL", self.enable_auto_s_s_l)
        writer.write_bool_value("EnableAvifVary", self.enable_avif_vary)
        writer.write_bool_value("EnableBunnyImageAi", self.enable_bunny_image_ai)
        writer.write_bool_value("EnableCacheSlice", self.enable_cache_slice)
        writer.write_bool_value("EnableCookieVary", self.enable_cookie_vary)
        writer.write_bool_value("EnableCountryCodeVary", self.enable_country_code_vary)
        writer.write_bool_value("EnableGeoZoneAF", self.enable_geo_zone_a_f)
        writer.write_bool_value("EnableGeoZoneASIA", self.enable_geo_zone_a_s_i_a)
        writer.write_bool_value("EnableGeoZoneEU", self.enable_geo_zone_e_u)
        writer.write_bool_value("EnableGeoZoneSA", self.enable_geo_zone_s_a)
        writer.write_bool_value("EnableGeoZoneUS", self.enable_geo_zone_u_s)
        writer.write_bool_value("EnableHostnameVary", self.enable_hostname_vary)
        writer.write_bool_value("EnableLogging", self.enable_logging)
        writer.write_bool_value("EnableMobileVary", self.enable_mobile_vary)
        writer.write_bool_value("EnableOriginShield", self.enable_origin_shield)
        writer.write_bool_value("EnableQueryStringOrdering", self.enable_query_string_ordering)
        writer.write_bool_value("EnableRequestCoalescing", self.enable_request_coalescing)
        writer.write_bool_value("EnableSafeHop", self.enable_safe_hop)
        writer.write_bool_value("EnableSmartCache", self.enable_smart_cache)
        writer.write_bool_value("EnableTLS1", self.enable_t_l_s1)
        writer.write_bool_value("EnableTLS1_1", self.enable_t_l_s1_1)
        writer.write_bool_value("EnableWebPVary", self.enable_web_p_vary)
        writer.write_str_value("ErrorPageCustomCode", self.error_page_custom_code)
        writer.write_bool_value("ErrorPageEnableCustomCode", self.error_page_enable_custom_code)
        writer.write_bool_value("ErrorPageEnableStatuspageWidget", self.error_page_enable_statuspage_widget)
        writer.write_str_value("ErrorPageStatuspageCode", self.error_page_statuspage_code)
        writer.write_bool_value("ErrorPageWhitelabel", self.error_page_whitelabel)
        writer.write_bool_value("FollowRedirects", self.follow_redirects)
        writer.write_bool_value("IgnoreQueryStrings", self.ignore_query_strings)
        writer.write_float_value("LimitRateAfter", self.limit_rate_after)
        writer.write_float_value("LimitRatePerSecond", self.limit_rate_per_second)
        writer.write_float_value("LogAnonymizationType", self.log_anonymization_type)
        writer.write_float_value("LogFormat", self.log_format)
        writer.write_bool_value("LogForwardingEnabled", self.log_forwarding_enabled)
        writer.write_float_value("LogForwardingFormat", self.log_forwarding_format)
        writer.write_str_value("LogForwardingHostname", self.log_forwarding_hostname)
        writer.write_int_value("LogForwardingPort", self.log_forwarding_port)
        writer.write_float_value("LogForwardingProtocol", self.log_forwarding_protocol)
        writer.write_str_value("LogForwardingToken", self.log_forwarding_token)
        writer.write_bool_value("LoggingIPAnonymizationEnabled", self.logging_i_p_anonymization_enabled)
        writer.write_bool_value("LoggingSaveToStorage", self.logging_save_to_storage)
        writer.write_int_value("LoggingStorageZoneId", self.logging_storage_zone_id)
        writer.write_str_value("MagicContainersAppId", self.magic_containers_app_id)
        writer.write_int_value("MagicContainersEndpointId", self.magic_containers_endpoint_id)
        writer.write_int_value("MiddlewareScriptId", self.middleware_script_id)
        writer.write_int_value("MonthlyBandwidthLimit", self.monthly_bandwidth_limit)
        writer.write_float_value("MonthlyCharges", self.monthly_charges)
        writer.write_str_value("Name", self.name)
        writer.write_bool_value("OptimizerAutomaticOptimizationEnabled", self.optimizer_automatic_optimization_enabled)
        writer.write_collection_of_object_values("OptimizerClasses", self.optimizer_classes)
        writer.write_int_value("OptimizerDesktopMaxWidth", self.optimizer_desktop_max_width)
        writer.write_bool_value("OptimizerEnableManipulationEngine", self.optimizer_enable_manipulation_engine)
        writer.write_bool_value("OptimizerEnableWebP", self.optimizer_enable_web_p)
        writer.write_bool_value("OptimizerEnabled", self.optimizer_enabled)
        writer.write_bool_value("OptimizerForceClasses", self.optimizer_force_classes)
        writer.write_int_value("OptimizerImageQuality", self.optimizer_image_quality)
        writer.write_bool_value("OptimizerMinifyCSS", self.optimizer_minify_c_s_s)
        writer.write_bool_value("OptimizerMinifyJavaScript", self.optimizer_minify_java_script)
        writer.write_int_value("OptimizerMobileImageQuality", self.optimizer_mobile_image_quality)
        writer.write_int_value("OptimizerMobileMaxWidth", self.optimizer_mobile_max_width)
        writer.write_bool_value("OptimizerStaticHtmlEnabled", self.optimizer_static_html_enabled)
        writer.write_str_value("OptimizerStaticHtmlWordPressBypassCookie", self.optimizer_static_html_word_press_bypass_cookie)
        writer.write_str_value("OptimizerStaticHtmlWordPressPath", self.optimizer_static_html_word_press_path)
        writer.write_bool_value("OptimizerWatermarkEnabled", self.optimizer_watermark_enabled)
        writer.write_int_value("OptimizerWatermarkMinImageSize", self.optimizer_watermark_min_image_size)
        writer.write_float_value("OptimizerWatermarkOffset", self.optimizer_watermark_offset)
        writer.write_float_value("OptimizerWatermarkPosition", self.optimizer_watermark_position)
        writer.write_str_value("OptimizerWatermarkUrl", self.optimizer_watermark_url)
        writer.write_int_value("OriginConnectTimeout", self.origin_connect_timeout)
        writer.write_str_value("OriginHostHeader", self.origin_host_header)
        writer.write_int_value("OriginResponseTimeout", self.origin_response_timeout)
        writer.write_int_value("OriginRetries", self.origin_retries)
        writer.write_bool_value("OriginRetryConnectionTimeout", self.origin_retry_connection_timeout)
        writer.write_int_value("OriginRetryDelay", self.origin_retry_delay)
        writer.write_bool_value("OriginRetryResponseTimeout", self.origin_retry_response_timeout)
        writer.write_bool_value("OriginRetry5XXResponses", self.origin_retry5_x_x_responses)
        writer.write_bool_value("OriginShieldEnableConcurrencyLimit", self.origin_shield_enable_concurrency_limit)
        writer.write_int_value("OriginShieldMaxConcurrentRequests", self.origin_shield_max_concurrent_requests)
        writer.write_int_value("OriginShieldMaxQueuedRequests", self.origin_shield_max_queued_requests)
        writer.write_int_value("OriginShieldQueueMaxWaitTime", self.origin_shield_queue_max_wait_time)
        writer.write_str_value("OriginShieldZoneCode", self.origin_shield_zone_code)
        writer.write_float_value("OriginType", self.origin_type)
        writer.write_str_value("OriginUrl", self.origin_url)
        writer.write_int_value("PermaCacheStorageZoneId", self.perma_cache_storage_zone_id)
        writer.write_int_value("PermaCacheType", self.perma_cache_type)
        writer.write_str_value("PreloadingScreenCode", self.preloading_screen_code)
        writer.write_bool_value("PreloadingScreenCodeEnabled", self.preloading_screen_code_enabled)
        writer.write_int_value("PreloadingScreenDelay", self.preloading_screen_delay)
        writer.write_bool_value("PreloadingScreenEnabled", self.preloading_screen_enabled)
        writer.write_str_value("PreloadingScreenLogoUrl", self.preloading_screen_logo_url)
        writer.write_bool_value("PreloadingScreenShowOnFirstVisit", self.preloading_screen_show_on_first_visit)
        writer.write_float_value("PreloadingScreenTheme", self.preloading_screen_theme)
        writer.write_collection_of_primitive_values("QueryStringVaryParameters", self.query_string_vary_parameters)
        writer.write_int_value("RequestCoalescingTimeout", self.request_coalescing_timeout)
        writer.write_int_value("RequestLimit", self.request_limit)
        writer.write_collection_of_enum_values("RoutingFilters", self.routing_filters)
        writer.write_bool_value("ShieldDDosProtectionEnabled", self.shield_d_dos_protection_enabled)
        writer.write_float_value("ShieldDDosProtectionType", self.shield_d_dos_protection_type)
        writer.write_int_value("StorageZoneId", self.storage_zone_id)
        writer.write_float_value("Type", self.type)
        writer.write_bool_value("UseBackgroundUpdate", self.use_background_update)
        writer.write_bool_value("UseStaleWhileOffline", self.use_stale_while_offline)
        writer.write_bool_value("UseStaleWhileUpdating", self.use_stale_while_updating)
        writer.write_bool_value("VerifyOriginSSL", self.verify_origin_s_s_l)
        writer.write_bool_value("ZoneSecurityEnabled", self.zone_security_enabled)
        writer.write_bool_value("ZoneSecurityIncludeHashRemoteIP", self.zone_security_include_hash_remote_i_p)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

class LoadFreeCertificateRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /pullzone/loadFreeCertificate
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new LoadFreeCertificateRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/pullzone/loadFreeCertificate?hostname={hostname}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> bytes:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        return request_info
    
    def with_url(self,raw_url: str) -> LoadFreeCertificateRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: LoadFreeCertificateRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return LoadFreeCertificateRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetQueryParameters():
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        """
        # The hostname that the certificate will be loaded for
        hostname: Optional[str] = None

    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetRequestConfiguration(RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.dmca_item_request_builder import DmcaItemRequestBuilder

class DmcaRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /dmca
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new DmcaRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/dmca", path_parameters)
    
    def by_id(self,id: int) -> DmcaItemRequestBuilder:
        """
        Gets an item from the BunnyApiClient.dmca.item collection
        param id: Unique identifier of the item
        Returns: DmcaItemRequestBuilder
        """
        if id is None:
            raise TypeError("id cannot be null.")
        from .item.dmca_item_request_builder import DmcaItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["id"] = id
        return DmcaItemRequestBuilder(self.request_adapter, url_tpl_params)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .edge_replication_regions import EdgeReplicationRegions
    from .standard_regions import StandardRegions

@dataclass
class StorageZoneCreate(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The Custom404FilePath property
    custom404_file_path: Optional[str] = None
    # The Name property
    name: Optional[str] = None
    # The OriginUrl property
    origin_url: Optional[str] = None
    # The Region property
    region: Optional[StandardRegions] = None
    # The ReplicationRegions property
    replication_regions: Optional[List[EdgeReplicationRegions]] = None
    # The Rewrite404To200 property
    rewrite404_to200: Optional[bool] = None
    # The ZoneTier property
    zone_tier: Optional[float] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> StorageZoneCreate:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: StorageZoneCreate
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return StorageZoneCreate()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .edge_replication_regions import EdgeReplicationRegions
        from .standard_regions import StandardRegions

        from .edge_replication_regions import EdgeReplicationRegions
        from .standard_regions import StandardRegions

        fields: Dict[str, Callable[[Any], None]] = {
            "Custom404FilePath": lambda n : setattr(self, 'custom404_file_path', n.get_str_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "OriginUrl": lambda n : setattr(self, 'origin_url', n.get_str_value()),
            "Region": lambda n : setattr(self, 'region', n.get_enum_value(StandardRegions)),
            "ReplicationRegions": lambda n : setattr(self, 'replication_regions', n.get_collection_of_enum_values(EdgeReplicationRegions)),
            "Rewrite404To200": lambda n : setattr(self, 'rewrite404_to200', n.get_bool_value()),
            "ZoneTier": lambda n : setattr(self, 'zone_tier', n.get_float_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("Custom404FilePath", self.custom404_file_path)
        writer.write_str_value("Name", self.name)
        writer.write_str_value("OriginUrl", self.origin_url)
        writer.write_enum_value("Region", self.region)
        writer.write_collection_of_enum_values("ReplicationRegions", self.replication_regions)
        writer.write_bool_value("Rewrite404To200", self.rewrite404_to200)
        writer.write_float_value("ZoneTier", self.zone_tier)
        writer.write_additional_data_value(self.additional_data)
    

